Support
=======


Sponsorship
-----------

With `donations and sponsorship`, you help make the projects
better. Donations allow the CourtBouillon team to have more time dedicated to
add new features, fix bugs, and improve documentation.

.. _donations and sponsorship: https://opencollective.com/courtbouillon


Professional Support
--------------------

You can improve your experience with CourtBouillon’s tools thanks to our
professional support. You want bugs fixed as soon as possible? Your projects
would highly benefit from some new features? You or your team would like to get
new skills with one of the technologies we master?

Please contact us by mail, by chat, or by tweet to get in touch and find the
best way we can help you.

.. _mail: mailto:contact@courtbouillon.org
.. _chat: https://gitter.im/CourtBouillon/tinycss2
.. _tweet: https://twitter.com/BouillonCourt
